==> openshift-model-operatorhub-5.7.3-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/MaintainerBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class MaintainerBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.MaintainerFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.MaintainerBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.Maintainer,io.fabric8.openshift.api.model.operatorhub.v1alpha1.MaintainerBuilder>{
  public MaintainerBuilder() {
    this(false);
  }
  public MaintainerBuilder(java.lang.Boolean validationEnabled) {
    this(new Maintainer(), validationEnabled);
  }
  public MaintainerBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.MaintainerFluent<?> fluent) {
    this(fluent, false);
  }
  public MaintainerBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.MaintainerFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Maintainer(), validationEnabled);
  }
  public MaintainerBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.MaintainerFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.Maintainer instance) {
    this(fluent, instance, false);
  }
  public MaintainerBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.MaintainerFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.Maintainer instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withEmail(instance.getEmail()); 
    fluent.withName(instance.getName()); 
    this.validationEnabled = validationEnabled; 
  }
  public MaintainerBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.Maintainer instance) {
    this(instance,false);
  }
  public MaintainerBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.Maintainer instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withEmail(instance.getEmail()); 
    this.withName(instance.getName()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.MaintainerFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.Maintainer build() {
    Maintainer buildable = new Maintainer(fluent.getEmail(),fluent.getName());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MaintainerBuilder that = (MaintainerBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-5.12.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/MaintainerBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class MaintainerBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.MaintainerFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.MaintainerBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.Maintainer,io.fabric8.openshift.api.model.operatorhub.v1alpha1.MaintainerBuilder>{
  public MaintainerBuilder() {
    this(false);
  }
  public MaintainerBuilder(java.lang.Boolean validationEnabled) {
    this(new Maintainer(), validationEnabled);
  }
  public MaintainerBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.MaintainerFluent<?> fluent) {
    this(fluent, false);
  }
  public MaintainerBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.MaintainerFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Maintainer(), validationEnabled);
  }
  public MaintainerBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.MaintainerFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.Maintainer instance) {
    this(fluent, instance, false);
  }
  public MaintainerBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.MaintainerFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.Maintainer instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withEmail(instance.getEmail()); 
    fluent.withName(instance.getName()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MaintainerBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.Maintainer instance) {
    this(instance,false);
  }
  public MaintainerBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.Maintainer instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withEmail(instance.getEmail()); 
    this.withName(instance.getName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.MaintainerFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.Maintainer build() {
    Maintainer buildable = new Maintainer(fluent.getEmail(),fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MaintainerBuilder that = (MaintainerBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
